@@ -1,18 +1,14 @@
 #' @import rlang
-#' @importFrom crayon
-#'   red bold
 NULL
 
 ## nocov start
 
-#' Cascadess
+#' Cascadess' CSS dependencies
 #'
-#' @description
+#' For CSS styles to be applied, you must include a call to
+#' `cascadess_dependencies()` in your UI or use the bslib package.
 #'
-#' Styles for htmltools tags.
-#'
-#' For styles to be applied you must include a call to `cascadess()` in your
-#' shiny application or htmltools tags.
+#' @returns An [htmltools::htmlDependency()].
 #'
 #' @export
 #' @examples
@@ -22,22 +18,38 @@ NULL
 #'
 #' shinyApp(
 #'   ui = list(
-#'     cascadess(),
+#'     cascadess_dependencies(),
 #'     div(
 #'       .style %>%
-#'         padding(3) %>%
-#'         background("indigo") %>%
-#'         font("light"),
+#'         padding_all(3) %>%
+#'         background_color(theme_light()),
 #'       "Etiam laoreet quam sed arcu."
 #'     )
 #'   ),
-#'   server = function(input, output) {
-#'
-#'   }
+#'   server = function(input, output) {}
 #' )
 #' }
 #'
-cascadess <- function() {
+#' \dontrun{
+#' library(shiny)
+#' library(bslib)
+#'
+#' shinyApp(
+#'   ui = page(
+#'     .style %>%
+#'       background_color(theme_primary()),
+#'     card(
+#'       .style %>%
+#'         margin_all(3) %>%
+#'         background_color(theme_light()),
+#'       "Hello, world!"
+#'     )
+#'   ),
+#'   server = function(input, output) {}
+#' )
+#' }
+#'
+cascadess_dependencies <- function() {
   htmltools::htmlDependency(
     name = "cascadess",
     version = utils::packageVersion("cascadess"),
